bayespy.inference.vmp.nodes.poisson.PoissonMoments.compute_dims_from_values
===========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonMoments.compute_dims_from_values